==> jc-train-cuizheng2-client-0.0.86-sources.jar: com/xforceplus/ultraman/app/jctraincuizheng2/controller/Autotestobjectcode2FeignApi.java <==
package com.xforceplus.ultraman.app.jctraincuizheng2.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-08-10
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctraincuizheng2.entity.Autotestobjectcode2;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-train-cuizheng2")
public interface Autotestobjectcode2FeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/autotestobjectcode2/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param autotestobjectcode2 ${table.comment}
   * @return R
   */
  @PostMapping("/autotestobjectcode2/add")
  public R save(@RequestBody Autotestobjectcode2 autotestobjectcode2);

  /**
   * 修改${table.comment}
   * @param autotestobjectcode2 ${table.comment}
   * @return R
   */
  @PostMapping("/autotestobjectcode2/update")
  public R updateById(@RequestBody Autotestobjectcode2 autotestobjectcode2);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/autotestobjectcode2/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-train-cuizheng2-client-2.0.323-sources.jar: com/xforceplus/ultraman/app/jctraincuizheng2/controller/Autotestobjectcode2FeignApi.java <==
package com.xforceplus.ultraman.app.jctraincuizheng2.controller;


/**
 * autotestobjectcode2feign客户端
 *
 * @author ultraman
 * @date 2021-11-14
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctraincuizheng2.entity.Autotestobjectcode2;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-train-cuizheng2")
public interface Autotestobjectcode2FeignApi {

  /**
   * 通过id查询autotestobjectcode2
   * @param  id
   * @return R
   */
  @GetMapping("/autotestobjectcode2/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增autotestobjectcode2
   * @param autotestobjectcode2 autotestobjectcode2
   * @return R
   */
  @PostMapping("/autotestobjectcode2/add")
  public R save(@RequestBody Autotestobjectcode2 autotestobjectcode2);

  /**
   * 修改autotestobjectcode2
   * @param autotestobjectcode2 autotestobjectcode2
   * @return R
   */
  @PostMapping("/autotestobjectcode2/update")
  public R updateById(@RequestBody Autotestobjectcode2 autotestobjectcode2);

  /**
   * 通过id删除autotestobjectcode2
   * @param  id
   * @return R
   */
  @DeleteMapping("/autotestobjectcode2/del/{id}" )
  public R removeById(@PathVariable Long id);

}
